tree

package
v0.23.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DirTree

func DirTree(root string, transform func(name string, info os.FileInfo) (bool, string)) (string, error)

DirTree generates a string representation of a directory tree, applying a transformation function to each file/directory.

func PrintStoreTree

func PrintStoreTree(store string) error

PrintStoreTree prints a tree-like representation of the password store. It filters out hidden files and appends a "/" to directory names.

Types

This section is empty.

Jump to