Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DirTree ¶
func DirTree(root string, transform func(name string, info os.FileInfo) (bool, string)) (string, error)
DirTree generates a string representation of a directory tree, applying a transformation function to each file/directory.
func PrintStoreTree ¶
PrintStoreTree prints a tree-like representation of the password store. It filters out hidden files and appends a "/" to directory names.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.